@@ -70,7 +70,7 @@
 			}
 			if (x$typeof == 0){
 				tmp <- cbind(coef, exp(coef), seH, seHIH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
-				if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq,x$dof_chisq,x$p.global_chisq)	
+				if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq,x$dof_chisq,x$p.global_chisq)
 			}else{
 				tmp <- cbind(coef, exp(coef), seH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
 				if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq,x$dof_chisq,x$p.global_chisq)
@@ -151,25 +151,34 @@
 				cat("\n")
 			}
 #AD:
-			if (x$typeof == 0){
-				if (x$logNormal == 0){
-					cat("    Frailty parameter, Theta:", frail, "(SE (H):",
-					seH, ")", "(SE (HIH):", seHIH, ")", "\n")
-				}else{
-					cat("    Frailty parameter, Sigma Square:", frail, "(SE (H):",
-					seH, ")", "(SE (HIH):", seHIH, ")", "\n")
-				}
+# 			if (x$typeof == 0){
+# 				if (x$logNormal == 0){
+# 					cat("    Frailty parameter, Theta:", frail, "(SE (H):",
+# 					seH, ")", "(SE (HIH):", seHIH, ")", "\n")
+# 				}else{
+# 					cat("    Frailty parameter, Sigma Square:", frail, "(SE (H):",
+# 					seH, ")", "(SE (HIH):", seHIH, ")", "\n")
+# 				}
+# 			}else{
+# 				if (x$logNormal == 0){
+# 					cat("    Frailty parameter, Theta:", frail, "(SE (H):",
+# 					seH, ")", "\n")
+# 				}else{
+# 					cat("    Frailty parameter, Sigma Square:", frail, "(SE (H):",
+# 					seH, ")", "\n")
+# 				}
+# 			}
+
+			if (x$logNormal == 0){
+				cat("    Frailty parameter, Theta:", frail, "(SE (H):",
+				seH, ")", "p =", signif(1 - pnorm(frail/seH), digits - 1), "\n")
 			}else{
-				if (x$logNormal == 0){
-					cat("    Frailty parameter, Theta:", frail, "(SE (H):",
-					seH, ")", "\n")
-				}else{
-					cat("    Frailty parameter, Sigma Square:", frail, "(SE (H):",
-					seH, ")", "\n")
-				}
+				cat("    Frailty parameter, Sigma Square:", frail, "(SE (H):",
+				seH, ")", "p =", signif(1 - pnorm(frail/seH), digits - 1), "\n")
 			}
-			
-        	}
+
+        }
+
 		cat(" \n")
 #AD:	
 		if (x$typeof == 0){
